@media print {
  .md-typeset {
    // Tabbed code block container
    .tabbed-set {
      display: block;

      .tabbed-content--wrap {
        display: inline-block;
        width: 100%;
        margin-bottom: 0.25rem;

        // Hide radio buttons
        > input {
          display: none;
        }

        > label {
          background-color: rgba($color: #aaa, $alpha: 0.2);
          padding: 0.2rem 2rem;
          margin: 0;
          font-weight: 600;
          color: #666;
          border-radius: 3px 3px 0 0;
          border-bottom-color: transparent;
        }

        > .tabbed-content {
          display: block;
          box-shadow: none;
        }
      }
    }

    // details
    > details summary::after {
        display: none;
    }

    // content indent
    &>div,
    &>div.admonition,
    &>details,
    &>div.tabbed-set,
    &>blockquote,
    &>mark,
    &>table,
    &>p {
      margin-left: 0.7rem;
    }
    &>table.highlighttable {
      margin: 0 0 0 0.7rem;
    }
    &>ul {
      margin-left: 1.5rem;
    }

    h4,
    h5,
    h6 {
      margin-left: 0.25rem;
    }

    *:not(h3) + h4 {
      margin-top: 1.5rem;
    }

    hr {
      border-bottom: 1px dotted #999;
    }

    .footnote {
      line-height: 1.1;
    }

    // Data tables
    table:not([class]) {
      th, td {
        padding: 0.5em 1.25rem 0.4em;
      }

      td {
        border-bottom: 1px solid #eee;
      }
    }
  }

  .md-typeset {
    span.twemoji {
      vertical-align: middle;
      height: 1.125rem;

      > img {
        height: 1.125rem;
        vertical-align: middle;
      }
    }
  }
}
