article {
  h1 {
    border-bottom: 2px solid #f00;
  }

  h2 {
    border-bottom: 1px solid #f99;
  }

  h3 {
    border-bottom: 0.5px solid #eee;
  }

  h1>.pdf-order,
  h2>.pdf-order,
  h3>.pdf-order {
    padding-left: 6px;
    // padding-right: 0.8rem;
  }
}
